@@ -26,6 +26,7 @@ The CodeBuild projects are configured as below
 
 * Logging to CloudWatch
 
+  * Configurable retention period. Default is one month.
   * Encryption using customer-managed KMS key
 
 ## Planned Features
@@ -43,6 +44,8 @@ The PAT needs to have "Code read" permission and stored in a SecretsManager secr
 aws secretsmanager create-secret --name rwest_archiver_rwest_platform --description "RWEST Archiver for RWEST-Platform organization" --secret-string "{\"pat\":\"<your_pat>\"}"
 ```
 
+## Example
+
 ## Links
 
 * [projen](https://github.com/projen/projen)
@@ -62,7 +65,9 @@ from typeguard import check_type
 
 from ._jsii import *
 
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
 import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
 import constructs as _constructs_77d1e7e8
 
 
@@ -81,11 +86,13 @@ class Archiver(
         id: builtins.str,
         *,
         backup_configurations: typing.Sequence[typing.Union["BackupConfiguration", typing.Dict[builtins.str, typing.Any]]],
+        retention_days: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
         :param backup_configurations: (experimental) Contains details on the git repositories to be backed up.
+        :param retention_days: (experimental) Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
 
         :stability: experimental
         '''
@@ -93,10 +100,30 @@ class Archiver(
             type_hints = typing.get_type_hints(_typecheckingstub__59b1d445ea6a4ea2b344c5e83eb14b7e5d57e243d55dbad607605e1e2e63c1b5)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        props = ArchiverProperties(backup_configurations=backup_configurations)
+        props = ArchiverProperties(
+            backup_configurations=backup_configurations, retention_days=retention_days
+        )
 
         jsii.create(self.__class__, self, [scope, id, props])
 
+    @builtins.property
+    @jsii.member(jsii_name="bucket")
+    def bucket(self) -> _aws_cdk_aws_s3_ceddda9d.Bucket:
+        '''(experimental) The S3 bucket used to store the git repositories archive.
+
+        :stability: experimental
+        :memberof: Archiver
+        :type: {s3.Bucket}
+        '''
+        return typing.cast(_aws_cdk_aws_s3_ceddda9d.Bucket, jsii.get(self, "bucket"))
+
+    @bucket.setter
+    def bucket(self, value: _aws_cdk_aws_s3_ceddda9d.Bucket) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__a6323f8f3cdbd2b11e534f545ef6432e903b1c3129b74f986595de806512f745)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "bucket", value)
+
     @builtins.property
     @jsii.member(jsii_name="logGroup")
     def log_group(self) -> _aws_cdk_aws_logs_ceddda9d.LogGroup:
@@ -115,6 +142,24 @@ class Archiver(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "logGroup", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="logGroupKmsKey")
+    def log_group_kms_key(self) -> _aws_cdk_aws_kms_ceddda9d.Key:
+        '''(experimental) The KMS key used to encrypt the logs.
+
+        :stability: experimental
+        :memberof: Archiver
+        :type: {kms.Key}
+        '''
+        return typing.cast(_aws_cdk_aws_kms_ceddda9d.Key, jsii.get(self, "logGroupKmsKey"))
+
+    @log_group_kms_key.setter
+    def log_group_kms_key(self, value: _aws_cdk_aws_kms_ceddda9d.Key) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__73a45d354e5f9a04dc155598cdf7614bfc4521dbdff7f8efd525a8166ff14705)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "logGroupKmsKey", value)
+
     @builtins.property
     @jsii.member(jsii_name="props")
     def props(self) -> "ArchiverProperties":
@@ -134,25 +179,33 @@ class Archiver(
 @jsii.data_type(
     jsii_type="azure-devops-repository-archiver.ArchiverProperties",
     jsii_struct_bases=[],
-    name_mapping={"backup_configurations": "backupConfigurations"},
+    name_mapping={
+        "backup_configurations": "backupConfigurations",
+        "retention_days": "retentionDays",
+    },
 )
 class ArchiverProperties:
     def __init__(
         self,
         *,
         backup_configurations: typing.Sequence[typing.Union["BackupConfiguration", typing.Dict[builtins.str, typing.Any]]],
+        retention_days: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
     ) -> None:
         '''
         :param backup_configurations: (experimental) Contains details on the git repositories to be backed up.
+        :param retention_days: (experimental) Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
 
         :stability: experimental
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__bfaace2f4df93a4fab67f960625a0f4057a1c4ba23833a63c0ffee999a9a724d)
             check_type(argname="argument backup_configurations", value=backup_configurations, expected_type=type_hints["backup_configurations"])
+            check_type(argname="argument retention_days", value=retention_days, expected_type=type_hints["retention_days"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "backup_configurations": backup_configurations,
         }
+        if retention_days is not None:
+            self._values["retention_days"] = retention_days
 
     @builtins.property
     def backup_configurations(self) -> typing.List["BackupConfiguration"]:
@@ -166,6 +219,21 @@ class ArchiverProperties:
         assert result is not None, "Required property 'backup_configurations' is missing"
         return typing.cast(typing.List["BackupConfiguration"], result)
 
+    @builtins.property
+    def retention_days(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays]:
+        '''(experimental) Number of days to keep the Cloudwatch logs.
+
+        :default: RetentionDays.ONE_MONTH
+
+        :stability: experimental
+        :memberof: ArchiverProperties
+        :type: {RetentionDays}
+        '''
+        result = self._values.get("retention_days")
+        return typing.cast(typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -291,6 +359,13 @@ def _typecheckingstub__59b1d445ea6a4ea2b344c5e83eb14b7e5d57e243d55dbad607605e1e2
     id: builtins.str,
     *,
     backup_configurations: typing.Sequence[typing.Union[BackupConfiguration, typing.Dict[builtins.str, typing.Any]]],
+    retention_days: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a6323f8f3cdbd2b11e534f545ef6432e903b1c3129b74f986595de806512f745(
+    value: _aws_cdk_aws_s3_ceddda9d.Bucket,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -301,6 +376,12 @@ def _typecheckingstub__9bb1a921963ed134fd11e5243da72c17693bf46b95bcb2787c98f86c2
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__73a45d354e5f9a04dc155598cdf7614bfc4521dbdff7f8efd525a8166ff14705(
+    value: _aws_cdk_aws_kms_ceddda9d.Key,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__fb1dff6681014d6e509e01d6b12c3974e4810c8d1a67b368174954a280d668f6(
     value: ArchiverProperties,
 ) -> None:
@@ -310,6 +391,7 @@ def _typecheckingstub__fb1dff6681014d6e509e01d6b12c3974e4810c8d1a67b368174954a28
 def _typecheckingstub__bfaace2f4df93a4fab67f960625a0f4057a1c4ba23833a63c0ffee999a9a724d(
     *,
     backup_configurations: typing.Sequence[typing.Union[BackupConfiguration, typing.Dict[builtins.str, typing.Any]]],
+    retention_days: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
 ) -> None:
     """Type checking stubs"""
     pass
